function filtered_im = filter_with_all_filters(im,filters)
%FILTER_WITH_ALL_FILTERS Filters image with array of filters.
%Filters input image (im) with the cell array containing the filter
%(filters).
%You can choose to normalize the results of each filtration by setting
%normalize_results to true.
%
% Written by Omri Perez, 2013, omriperez(at)gmail(dot)com

normalize_results=false; %normalize result to [0,1]?


f=filters(:); %delineate filter cell matrix
filter_num=length(f);
filtered_im=0;


for f_idx=1:filter_num
    %filter using current filter
    temp= imfilter(im, f{f_idx},'symmetric','conv');
    %normalize result to [0,1]?
    if normalize_results
        temp=temp-min(temp(:));
        temp=temp./max(temp(:));
    end
    %accumulate all filtered results
    filtered_im=filtered_im+temp; 
end

%average results over filter results
filtered_im=filtered_im./filter_num;

end