function [ filters ] = generate_filters( rows,cols,sizes, orientations, phases)
%GENERATE_FILTERS  - generates collection of gabor filters
%rows - number of rows in image.
%cols - number of columns in image.
%sizes - vector of sizes for the the filters. the size is a ratio of the
%image size.
%orientations - vector of orientation angles for the filters (in degrees,
%0 degrees points up).
%phases - vector of phases for the filters. 0.25 is even symmetry: 
%    /\
% --/  \--
%
% and 1 is odd symmetry: 
%      /\
% -\  /  \-
%   \/
% Returns a cell array of filters
%
% Written by Omri Perez, 2013, omriperez(at)gmail(dot)com

if nargin<3 %size of filters as ratio of image size
    sizes=[0.02,0.04,0.08];
end

if nargin<4
orientations=[0,45,90,135]; %in degrees: | / - \
end

if nargin<5
phases=[0.25,0.1]; % even and odd symmetries
end


max_dim=max(rows,cols);
sizes=ceil(sizes.*max_dim);

lambda = 0.3;   % filter-size-normalized sinus wavelength (pixels per cycles)
sigma =0.15;     % filter-size-normalized gaussian standard deviation in 
% pixels, if 0 then don't apply gaussian


filters=cell(length(orientations),length(phases),length(sizes));

%generate gabor filters
for i=1:length(orientations)
    for j=1:length(phases)
        for k=1:length(sizes)         
            filt=gaborFn(sizes(k), lambda*sizes(k), sigma*sizes(k), orientations(i), phases(j));
            filters{i,j,k}=filt;
        end
    end
end